import {select, arc , geoPath , geoAlbersUsa, geoOrthographic, geoStereographic, 
        geoNaturalEarth1, zoom, event, scaleOrdinal, 
        schemeCategory10,
        schemeReds} from 'd3';

import {loadAndProcessData} from './loadAndProcessData';
import {colorLegend} from './colorLegend';
import {useData} from './useData';

const svg = d3.select("svg");

//const projection = geoMercator();
//const projection = geoOrthographic();
//const projection = geoStereographic();
const projection = geoAlbersUsa();

const g= svg.append('g');
const colorLegendGroup = 
      svg.append('g')
		.attr('transform',`translate(20,420)`);

const pathGenerator = geoPath().projection(projection);
g.append('path')
			.attr('class', 'globe')
			.attr('d', pathGenerator({type: 'Sphere'}));

function zoomed() { svg.attr('transform', d3.event.transform);}
svg.call(zoom().on('zoom', () => {g.attr('transform', event.transform)	}));

loadAndProcessData().then(
  states=>
  {

  const paths=g.selectAll('path').data(states.features);
  paths.enter().append('path')
    .attr('class', 'state')
    .attr('d', d => pathGenerator(d))
    .append('title')
    .attr(
      'href',
      `https://github.com/d3/d3-geo-projection`
    )
  }
  
  );

export const Marks = ({ data }) => (
  <g className="marks">
    {data.map(d => {
      const [x, y] = projection([d.longitude, d.latitude]);
      return <circle 
               cx={x}
               cy={y}
               r={5}
              >
             	<title> place holder </title>
        	 	 </circle>
    })}
  </g>
);

const width = 960;
const height = 500;

const App = () => {
  const data = useData();

  if (!data) { 
    return <pre>Loading...</pre>;
  }

return (
  <svg width={width} height={height}>
    <BubbleMap data={data}/>
  </svg>
	);
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
/*
World Atlas data (countries-110m.json) is in TopoJSON format.
D3 geo libraries can work with GeoJSON.
Therefore the TopoJSON-data needs to be converted to GeoJSON
in order to generate svg-paths using D3.
This is done with the geoPath-library.

In this script two generator functions are created:
1. projection: generate map projection
2. pathGenerator: convert TopoJSON to GeoJSON, then project it using the projection

*/






