import { useState, useEffect } from 'react';
import { tsv, json, csv} from 'd3';
import {feature } from 'topojson';

export const loadAndProcessData = () =>

  /* Use Promise.all to make sure that waits for multiple promises, before
     the callback function passed in .then() is executed 
   */
  Promise.all([
    tsv('https://unpkg.com/world-atlas@1/world/110m.tsv'),
    json('https://unpkg.com/us-atlas@3.0.0/states-10m.json')
    ])
    .then(([tsvData, topoJSONData]) => {

    /* Using reduce */
    /* reduce 
        1) parameters:
          - accumulator function which is returned by reduce 
          - the data element / row
        2) initial value for the accumulator

        In the first invocation the initial value is an empty object
        Every invocation will return the accumulator object.
        The accumulator object is then passed in as a parameter on
        each invocation, thus "accumulating" information for each data element.

    */

    const rowById = tsvData.reduce((accumulator, d) => {
      accumulator[d.iso_n3]=d;
      return accumulator;
    	}, {});

    /* Using forEach */
    /*
    const countryName = {};
    tsvData.forEach(d => {countryName[d.iso_n3]=d.name})
    */
	
    const states = feature(topoJSONData, topoJSONData.objects.states);
    states.features.forEach(d => {
      Object.assign(d.properties, rowById[d.id]);
    });
    console.log(states);
    return states;
    });